Touches |
--- | ---
F1 | Onde P-Pdif
F2 | Onde PKP
F3 | Onde PP
F4 | Onde SKS
F5 | Onde S-SKKS
F6 | Onde SP
F7 | Onde SS
F8 | Onde LOVE
F9 | Onde RAYL
q | Quitter
r | Recharger les fichiers modifiés
R | Recharger les Snufflings
f | Basculer en mode plein écran
m | Basculer la barre latérale des marqueurs
c | Basculer les contrôles principaux
: | Entrer une commande
<espace> | Avancer d'une page dans le temps
b | Reculer d'une page dans le temps
<pagedown> | Faire défiler les pistes d'une page vers le bas
<pageup> | Faire défiler les pistes d'une page vers le haut
+ | Afficher une piste supplémentaire
- | Afficher une piste de moins
= | Afficher le nombre initial de pistes
g | Aller à la sélection / tout afficher
G | Zoomer sur la sélection / zoomer sur la visibilité des traces
n | Aller au marqueur suivant
p | Aller au marqueur précédent
N | Aller au marqueur d'événement suivant
P | Aller au marqueur d'événement précédent
<tab> | Aller au marqueur suivant de l'événement actif
<shift> + <tab> | Aller au marqueur précédent de l'événement actif
a | Sélectionner tous les marqueurs actuellement visibles
A | Sélectionner tous les marqueurs
d | Désélectionner tous les marqueurs
0 ... 5 | Changer la couleur du marqueur
<f1> ... <f5> | Convertir en marqueur de phase
e | Convertir en marqueur d'événement / définir l'événement actif / associer à un événement
E | Désactiver l'événement
<f10> | Convertir le marqueur de phase en marqueur normal
<backspace> | Supprimer le marqueur
<haut>, <bas> | Définir la polarité du premier mouvement sur le marqueur sélectionné
<shift> + <haut>, <shift> + <bas> | Annuler la polarité du premier mouvement sur le marqueur sélectionné
<escape> | Annuler le picking
? | Aide

Souris |
--- | ---
Cliquer et glisser | Zoom et défilement
Cliquer et glisser sur l'axe du temps | Défilement horizontal seulement
Cliquer sur le marqueur | Sélectionner le marqueur
<shift> + cliquer sur le marqueur | Sélectionner un marqueur supplémentaire
Molette | Défilement vertical des pistes
<ctrl> + molette | Modifier le nombre de pistes affichées
Double-clic | Entrer en mode de picking

Commandes |
--- | ---
`n|s|l|c [ <pattern> ]` | Réduire les traces à celles correspondant à un motif donné. man
`hide <pattern> hide n|s|l|c <pattern>` | Masquer les traces dont les identifiants de réseau, de station, de localisation et de canal correspondent à un motif donné. man
`unhide <pattern> unhide n|s|l|c <pattern>` | Afficher les traces précédemment masquées avec la commande hide. man
`markers [0][1][2][3][4][5] markers all markers` | Basculer la visibilité des marqueurs. man
`scaling <vmin> <vmax> scaling <pattern> <vmin> <vmax> scaling` | Définir les règles de mise à l'échelle. man
`goto YYYY-MM[-DD[ HH[:MM[:SS[.XXX]]]]] goto HH:MM[:SS[.XXX]] goto <eventname>` | Aller à un moment ou à un événement donné. man